@@ -30,9 +30,7 @@ class ImageRecognizer(object):
         self.prepare_img()
 
     def get_dst_img_file(self):
-        return (
-            self.dst_img_dir + os.path.sep + self.img_name
-        )
+        return self.dst_img_dir + os.path.sep + self.img_name
 
     def get_dst_img_file_json(self):
         return "%s.json" % self.get_dst_img_file()
